# Table of Contents

- [delta-to-meta-model-v3](<./delta-to-meta-model-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Delta to Meta Model v3](<./Delta-to-Meta-Model-v3.md>)
  - [Quick links](<./Delta-to-Meta-Model-v3/Quick-links.md>)
  - [Why has SAP LeanIX changed its Meta Model?](<./Delta-to-Meta-Model-v3/Why-has-SAP-LeanIX-changed-its-Meta-Model.md>)
  - [What is the delta between the Meta Model v4 and the Meta Model v3?](<./Delta-to-Meta-Model-v3/What-is-the-delta-between-the-Meta-Model-v4-and-the-Meta-Model-v3.md>)
  - [Q&A on detailed changes](<./Delta-to-Meta-Model-v3/QA-on-detailed-changes.md>)
  - [Was this page helpful?](<./Delta-to-Meta-Model-v3/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Delta-to-Meta-Model-v3/Wed-love-your-feedback.md>)
